@@ -987,7 +987,7 @@ ZEND_FUNCTION(get_object_vars)
 	HashPosition pos;
 	char *key;
 	const char *prop_name, *class_name;
-	uint key_len;
+	uint key_len, prop_len;
 	ulong num_index;
 	zend_object *zobj;
 
@@ -1014,10 +1014,10 @@ ZEND_FUNCTION(get_object_vars)
 	while (zend_hash_get_current_data_ex(properties, (void **) &value, &pos) == SUCCESS) {
 		if (zend_hash_get_current_key_ex(properties, &key, &key_len, &num_index, 0, &pos) == HASH_KEY_IS_STRING) {
 			if (zend_check_property_access(zobj, key, key_len-1 TSRMLS_CC) == SUCCESS) {
-				zend_unmangle_property_name(key, key_len-1, &class_name, &prop_name);
+				zend_unmangle_property_name_ex(key, key_len - 1, &class_name, &prop_name, (int*) &prop_len);
 				/* Not separating references */
 				Z_ADDREF_PP(value);
-				add_assoc_zval_ex(return_value, prop_name, strlen(prop_name)+1, *value);
+				add_assoc_zval_ex(return_value, prop_name, prop_len + 1, *value);
 			}
 		}
 		zend_hash_move_forward_ex(properties, &pos);
@@ -1524,7 +1524,6 @@ ZEND_FUNCTION(trigger_error)
 ZEND_FUNCTION(set_error_handler)
 {
 	zval *error_handler;
-	zend_bool had_orig_error_handler=0;
 	char *error_handler_name = NULL;
 	long error_type = E_ALL;
 
@@ -1532,38 +1531,31 @@ ZEND_FUNCTION(set_error_handler)
 		return;
 	}
 
-	if (!zend_is_callable(error_handler, 0, &error_handler_name TSRMLS_CC)) {
-		zend_error(E_WARNING, "%s() expects the argument (%s) to be a valid callback",
-				   get_active_function_name(TSRMLS_C), error_handler_name?error_handler_name:"unknown");
+	if (Z_TYPE_P(error_handler) != IS_NULL) { /* NULL == unset */
+		if (!zend_is_callable(error_handler, 0, &error_handler_name TSRMLS_CC)) {
+			zend_error(E_WARNING, "%s() expects the argument (%s) to be a valid callback",
+					   get_active_function_name(TSRMLS_C), error_handler_name?error_handler_name:"unknown");
+			efree(error_handler_name);
+			return;
+		}
 		efree(error_handler_name);
-		return;
 	}
-	efree(error_handler_name);
 
 	if (EG(user_error_handler)) {
-		had_orig_error_handler = 1;
-		*return_value = *EG(user_error_handler);
-		zval_copy_ctor(return_value);
-		INIT_PZVAL(return_value);
+		RETVAL_ZVAL(EG(user_error_handler), 1, 0);
+
 		zend_stack_push(&EG(user_error_handlers_error_reporting), &EG(user_error_handler_error_reporting), sizeof(EG(user_error_handler_error_reporting)));
 		zend_ptr_stack_push(&EG(user_error_handlers), EG(user_error_handler));
 	}
-	ALLOC_ZVAL(EG(user_error_handler));
 
-	if (!zend_is_true(error_handler)) { /* unset user-defined handler */
-		FREE_ZVAL(EG(user_error_handler));
+	if (Z_TYPE_P(error_handler) == IS_NULL) { /* unset user-defined handler */
 		EG(user_error_handler) = NULL;
-		RETURN_TRUE;
+		return;
 	}
 
+	ALLOC_ZVAL(EG(user_error_handler));
+	MAKE_COPY_ZVAL(&error_handler, EG(user_error_handler));
 	EG(user_error_handler_error_reporting) = (int)error_type;
-	*EG(user_error_handler) = *error_handler;
-	zval_copy_ctor(EG(user_error_handler));
-	INIT_PZVAL(EG(user_error_handler));
-
-	if (!had_orig_error_handler) {
-		RETURN_NULL();
-	}
 }
 /* }}} */
 
@@ -1597,7 +1589,6 @@ ZEND_FUNCTION(set_exception_handler)
 {
 	zval *exception_handler;
 	char *exception_handler_name = NULL;
-	zend_bool had_orig_exception_handler=0;
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &exception_handler) == FAILURE) {
 		return;
@@ -1614,24 +1605,18 @@ ZEND_FUNCTION(set_exception_handler)
 	}
 
 	if (EG(user_exception_handler)) {
-		had_orig_exception_handler = 1;
-		*return_value = *EG(user_exception_handler);
-		zval_copy_ctor(return_value);
+		RETVAL_ZVAL(EG(user_exception_handler), 1, 0);
+
 		zend_ptr_stack_push(&EG(user_exception_handlers), EG(user_exception_handler));
 	}
-	ALLOC_ZVAL(EG(user_exception_handler));
 
 	if (Z_TYPE_P(exception_handler) == IS_NULL) { /* unset user-defined handler */
-		FREE_ZVAL(EG(user_exception_handler));
 		EG(user_exception_handler) = NULL;
-		RETURN_TRUE;
+		return;
 	}
 
+	ALLOC_ZVAL(EG(user_exception_handler));
 	MAKE_COPY_ZVAL(&exception_handler, EG(user_exception_handler))
-
-	if (!had_orig_exception_handler) {
-		RETURN_NULL();
-	}
 }
 /* }}} */
 
@@ -2452,49 +2437,36 @@ ZEND_FUNCTION(extension_loaded)
    Returns an array with the names of functions belonging to the named extension */
 ZEND_FUNCTION(get_extension_funcs)
 {
-	char *extension_name, *lcname;
-	int extension_name_len, array;
+	char *extension_name;
+	int extension_name_len;
 	zend_module_entry *module;
-	HashPosition iterator;
-	zend_function *zif;
+	const zend_function_entry *func;
+
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &extension_name, &extension_name_len) == FAILURE) {
 		return;
 	}
+
 	if (strncasecmp(extension_name, "zend", sizeof("zend"))) {
-		lcname = zend_str_tolower_dup(extension_name, extension_name_len);
-	} else {
-		lcname = estrdup("core");
-	}
-	if (zend_hash_find(&module_registry, lcname,
-		extension_name_len+1, (void**)&module) == FAILURE) {
-		efree(lcname);
-		RETURN_FALSE;
-	}
-
-	zend_hash_internal_pointer_reset_ex(CG(function_table), &iterator);
-	if (module->functions) {
-		/* avoid BC break, if functions list is empty, will return an empty array */
-		array_init(return_value);
-		array = 1;
-	} else {
-		array = 0;
-	}
-	while (zend_hash_get_current_data_ex(CG(function_table), (void **) &zif, &iterator) == SUCCESS) {
-		if (zif->common.type==ZEND_INTERNAL_FUNCTION
-			&& zif->internal_function.module == module) {
-			if (!array) {
-				array_init(return_value);
-				array = 1;
-			}
-			add_next_index_string(return_value, zif->common.function_name, 1);
+		char *lcname = zend_str_tolower_dup(extension_name, extension_name_len);
+		if (zend_hash_find(&module_registry, lcname,
+			extension_name_len+1, (void**)&module) == FAILURE) {
+			efree(lcname);
+			RETURN_FALSE;
 		}
-		zend_hash_move_forward_ex(CG(function_table), &iterator);
+		efree(lcname);
+
+		if (!(func = module->functions)) {
+			RETURN_FALSE;
+		}
+	} else {
+		func = builtin_functions;
 	}
 
-	efree(lcname);
+	array_init(return_value);
 
-	if (!array) {
-		RETURN_FALSE;
+	while (func->fname) {
+		add_next_index_string(return_value, func->fname, 1);
+		func++;
 	}
 }
 /* }}} */
