@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2014 The PHP Group                                |
+   | Copyright (c) 1997-2013 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -53,7 +53,7 @@ static void safe_array_from_zval(VARIANT *v, zval *z, int codepage TSRMLS_DC)
 
 		if (HASH_KEY_IS_STRING == keytype) {
 			goto bogus;
-		} else if (HASH_KEY_NON_EXISTANT == keytype) {
+		} else if (HASH_KEY_NON_EXISTENT == keytype) {
 			break;
 		}
 		if (intindex > max_index) {
