@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2012 The PHP Group                                |
+   | Copyright (c) 1997-2013 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -104,7 +104,7 @@ Since:
 */
 PHP_FUNCTION(dom_nodelist_item)
 {
-	zval *id, *rv = NULL;
+	zval *id;
 	long index;
 	int ret;
 	dom_object *intern;
@@ -163,7 +163,7 @@ PHP_FUNCTION(dom_nodelist_item)
 		}
 
 		if (itemnode) {
-			DOM_RET_OBJ(rv, itemnode, &ret, objmap->baseobj);
+			DOM_RET_OBJ(itemnode, &ret, objmap->baseobj);
 			return;
 		}
 	}
