@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2014 The PHP Group                                |
+   | Copyright (c) 1997-2013 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -238,10 +238,10 @@ ZEND_END_ARG_INFO()
 /* }}} */
 
 const zend_function_entry mcrypt_functions[] = { /* {{{ */
-	PHP_FE(mcrypt_ecb, 				arginfo_mcrypt_ecb)
-	PHP_FE(mcrypt_cbc, 				arginfo_mcrypt_cbc)
-	PHP_FE(mcrypt_cfb, 				arginfo_mcrypt_cfb)
-	PHP_FE(mcrypt_ofb, 				arginfo_mcrypt_ofb)
+	PHP_DEP_FE(mcrypt_ecb, 				arginfo_mcrypt_ecb)
+	PHP_DEP_FE(mcrypt_cbc, 				arginfo_mcrypt_cbc)
+	PHP_DEP_FE(mcrypt_cfb, 				arginfo_mcrypt_cfb)
+	PHP_DEP_FE(mcrypt_ofb, 				arginfo_mcrypt_ofb)
 	PHP_FE(mcrypt_get_key_size, 	arginfo_mcrypt_get_key_size)
 	PHP_FE(mcrypt_get_block_size, 	arginfo_mcrypt_get_block_size)
 	PHP_FE(mcrypt_get_cipher_name, 	arginfo_mcrypt_get_cipher_name)
@@ -619,11 +619,8 @@ PHP_FUNCTION(mcrypt_generic_init)
 
 	if (iv_len != iv_size) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Iv size incorrect; supplied length: %d, needed: %d", iv_len, iv_size);
-		if (iv_len > iv_size) {
-			iv_len = iv_size;
-		}
 	}
-	memcpy(iv_s, iv, iv_len);
+	memcpy(iv_s, iv, iv_size);
 
 	mcrypt_generic_deinit(pm->td);
 	result = mcrypt_generic_init(pm->td, key_s, key_size, iv_s);
@@ -644,9 +641,8 @@ PHP_FUNCTION(mcrypt_generic_init)
 				php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unknown error");
 				break;
 		}
-	} else {
-		pm->init = 1;
 	}
+	pm->init = 1;
 	RETVAL_LONG(result);
 
 	efree(iv_s);
@@ -1391,7 +1387,7 @@ PHP_FUNCTION(mcrypt_create_iv)
 	}
 	
 	iv = ecalloc(size + 1, 1);
-
+	
 	if (source == RANDOM || source == URANDOM) {
 #if PHP_WIN32
 		/* random/urandom equivalent on Windows */
