@@ -410,7 +410,7 @@ static int phar_stream_seek(php_stream *stream, off_t offset, int whence, off_t
 		case SEEK_SET :
 			temp = data->zero + offset;
 			break;
-		default :
+		default:
 			temp = 0;
 	}
 	if (temp > data->zero + (off_t) entry->uncompressed_filesize) {
@@ -635,7 +635,7 @@ static int phar_wrapper_stat(php_stream_wrapper *wrapper, char *url, int flags,
 
 		zend_hash_internal_pointer_reset_ex(&phar->mounted_dirs, &pos);
 		while (FAILURE != zend_hash_has_more_elements_ex(&phar->mounted_dirs, &pos)) {
-			if (HASH_KEY_NON_EXISTANT == zend_hash_get_current_key_ex(&phar->mounted_dirs, &key, &keylen, &unused, 0, &pos)) {
+			if (HASH_KEY_NON_EXISTENT == zend_hash_get_current_key_ex(&phar->mounted_dirs, &key, &keylen, &unused, 0, &pos)) {
 				break;
 			}
 			PHAR_STR(key, str_key);
@@ -918,7 +918,7 @@ static int phar_wrapper_rename(php_stream_wrapper *wrapper, char *url_from, char
 		uint to_len = strlen(resource_to->path+1);
 
 		for (zend_hash_internal_pointer_reset(&phar->manifest);
-			HASH_KEY_NON_EXISTANT != (key_type = zend_hash_get_current_key_ex(&phar->manifest, &key, &key_len, &unused, 0, NULL)) &&
+			HASH_KEY_NON_EXISTENT != (key_type = zend_hash_get_current_key_ex(&phar->manifest, &key, &key_len, &unused, 0, NULL)) &&
 			SUCCESS == zend_hash_get_current_data(&phar->manifest, (void **) &entry);
 			zend_hash_move_forward(&phar->manifest)) {
 
@@ -952,7 +952,7 @@ static int phar_wrapper_rename(php_stream_wrapper *wrapper, char *url_from, char
 		}
 
 		for (zend_hash_internal_pointer_reset(&phar->virtual_dirs);
-			HASH_KEY_NON_EXISTANT != (key_type = zend_hash_get_current_key_ex(&phar->virtual_dirs, &key, &key_len, &unused, 0, NULL));
+			HASH_KEY_NON_EXISTENT != (key_type = zend_hash_get_current_key_ex(&phar->virtual_dirs, &key, &key_len, &unused, 0, NULL));
 			zend_hash_move_forward(&phar->virtual_dirs)) {
 
 			PHAR_STR(key, str_key);
@@ -979,7 +979,7 @@ static int phar_wrapper_rename(php_stream_wrapper *wrapper, char *url_from, char
 		}
 
 		for (zend_hash_internal_pointer_reset(&phar->mounted_dirs);
-			HASH_KEY_NON_EXISTANT != (key_type = zend_hash_get_current_key_ex(&phar->mounted_dirs, &key, &key_len, &unused, 0, NULL)) &&
+			HASH_KEY_NON_EXISTENT != (key_type = zend_hash_get_current_key_ex(&phar->mounted_dirs, &key, &key_len, &unused, 0, NULL)) &&
 			SUCCESS == zend_hash_get_current_data(&phar->mounted_dirs, (void **) &entry);
 			zend_hash_move_forward(&phar->mounted_dirs)) {
 
