@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2012 The PHP Group                                |
+   | Copyright (c) 1997-2013 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -23,7 +23,7 @@
 #include "mod_user.h"
 
 ps_module ps_mod_user = {
-	PS_MOD(user)
+	PS_MOD_SID(user)
 };
 
 #define SESS_ZVAL_LONG(val, a)						\
@@ -62,14 +62,9 @@ static zval *ps_call_handler(zval *func, int argc, zval **argv TSRMLS_DC)
 	return retval;
 }
 
-#define STDVARS1							\
-	zval *retval;							\
-	int ret = FAILURE
-
 #define STDVARS								\
-	STDVARS1;								\
-	char *mdata = PS_GET_MOD_DATA();		\
-	if (!mdata) { return FAILURE; }
+	zval *retval = NULL;					\
+	int ret = FAILURE
 
 #define PSF(a) PS(mod_user_names).name.ps_##a
 
@@ -84,8 +79,7 @@ static zval *ps_call_handler(zval *func, int argc, zval **argv TSRMLS_DC)
 PS_OPEN_FUNC(user)
 {
 	zval *args[2];
-	static char dummy = 0;
-	STDVARS1;
+	STDVARS;
 	
 	if (PSF(open) == NULL) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING,
@@ -98,25 +92,35 @@ PS_OPEN_FUNC(user)
 	SESS_ZVAL_STRING((char*)session_name, args[1]);
 
 	retval = ps_call_handler(PSF(open), 2, args TSRMLS_CC);
-	if (retval) {
-		/* This is necessary to fool the session module. Yes, it's safe to
-		 * use a static. Neither mod_user nor the session module itself will
-		 * ever touch this pointer. It could be set to 0xDEADBEEF for all the
-		 * difference it makes, but for the sake of paranoia it's set to some
-		 * valid value. */
-		PS_SET_MOD_DATA(&dummy);
-	}
+	PS(mod_user_implemented) = 1;
 
 	FINISH;
 }
 
 PS_CLOSE_FUNC(user)
 {
-	STDVARS1;
+	zend_bool bailout = 0;
+	STDVARS;
 
-	retval = ps_call_handler(PSF(close), 0, NULL TSRMLS_CC);
+	if (!PS(mod_user_implemented)) {
+		/* already closed */
+		return SUCCESS;
+	}
 
-	PS_SET_MOD_DATA(NULL);
+	zend_try {
+		retval = ps_call_handler(PSF(close), 0, NULL TSRMLS_CC);
+	} zend_catch {
+		bailout = 1;
+	} zend_end_try();
+
+	PS(mod_user_implemented) = 0;
+
+	if (bailout) {
+		if (retval) {
+			zval_ptr_dtor(&retval);
+		}
+		zend_bailout();
+	}
 
 	FINISH;
 }
@@ -179,6 +183,38 @@ PS_GC_FUNC(user)
 	FINISH;
 }
 
+PS_CREATE_SID_FUNC(user)
+{
+	/* maintain backwards compatibility */
+	if (PSF(create_sid) != NULL) {
+		char *id = NULL;
+		zval *retval = NULL;
+
+		retval = ps_call_handler(PSF(create_sid), 0, NULL TSRMLS_CC);
+
+		if (retval) {
+			if (Z_TYPE_P(retval) == IS_STRING) {
+				id = estrndup(Z_STRVAL_P(retval), Z_STRLEN_P(retval));
+			}
+			zval_ptr_dtor(&retval);
+		}
+		else {
+			php_error_docref(NULL TSRMLS_CC, E_ERROR, "No session id returned by function");
+			return NULL;
+		}
+
+		if (!id) {
+			php_error_docref(NULL TSRMLS_CC, E_ERROR, "Session id must be a string");
+			return NULL;
+		}
+
+		return id;
+	}
+
+	/* function as defined by PS_MOD */
+	return php_session_create_id(mod_data, newlen TSRMLS_CC);
+}
+
 /*
  * Local variables:
  * tab-width: 4
